Predictors
==========

.. automodule:: stonesoup.predictor
    :no-members:

.. automodule:: stonesoup.predictor.base
    :show-inheritance:

Kalman
------

.. automodule:: stonesoup.predictor.kalman
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.predictor.particle
    :show-inheritance:
